@@ -5,29 +5,56 @@ use serde::{Deserialize, Serialize};
 use std::collections::HashSet;
 use std::path::PathBuf;
 
+/// Dependency handling for autoconf-based projects.
 pub mod autoconf;
 #[cfg(feature = "debian")]
+/// Dependency handling for Debian packages.
 pub mod debian;
+/// Dependency handling for Go projects.
 pub mod go;
+/// Dependency handling for Haskell projects.
 pub mod haskell;
+/// Dependency handling for Java projects.
 pub mod java;
+/// Dependency handling for LaTeX projects.
 pub mod latex;
+/// Dependency handling for Node.js projects.
 pub mod node;
+/// Dependency handling for GNU Octave projects.
 pub mod octave;
+/// Dependency handling for Perl projects.
 pub mod perl;
+/// Dependency handling for PHP projects.
 pub mod php;
+/// Dependency handling for pytest-specific dependencies.
 pub mod pytest;
+/// Dependency handling for Python projects.
 pub mod python;
+/// Dependency handling for R projects.
 pub mod r;
+/// Dependency handling for vague or generic dependencies.
 pub mod vague;
+/// Dependency handling for XML-related requirements.
 pub mod xml;
 
+/// Dependency on a system binary or executable file.
+///
+/// This represents a dependency on an executable binary command that
+/// must be available in the PATH.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct BinaryDependency {
+    /// Name of the binary executable
     binary_name: String,
 }
 
 impl BinaryDependency {
+    /// Create a new BinaryDependency.
+    ///
+    /// # Arguments
+    /// * `binary_name` - Name of the binary executable
+    ///
+    /// # Returns
+    /// A new BinaryDependency instance
     pub fn new(binary_name: &str) -> Self {
         Self {
             binary_name: binary_name.to_string(),
@@ -71,6 +98,7 @@ impl ToDependency for buildlog_consultant::problems::common::MissingCommandOrBui
     }
 }
 
+#[cfg(feature = "debian")]
 const BIN_PATHS: &[&str] = &["/usr/bin", "/bin"];
 
 #[cfg(feature = "debian")]
@@ -98,12 +126,24 @@ impl crate::dependencies::debian::IntoDebianDependency for BinaryDependency {
     }
 }
 
+/// Dependency for accessing VCS control directories.
+///
+/// This represents a dependency on access to VCS control directories
+/// like .git, .svn, etc., which might be needed by certain build processes.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct VcsControlDirectoryAccessDependency {
+    /// List of affected version control systems (e.g., "git", "svn")
     pub vcs: Vec<String>,
 }
 
 impl VcsControlDirectoryAccessDependency {
+    /// Create a new VcsControlDirectoryAccessDependency.
+    ///
+    /// # Arguments
+    /// * `vcs` - List of version control systems
+    ///
+    /// # Returns
+    /// A new VcsControlDirectoryAccessDependency instance
     pub fn new(vcs: Vec<&str>) -> Self {
         Self {
             vcs: vcs.iter().map(|s| s.to_string()).collect(),
@@ -178,12 +218,24 @@ impl ToDependency for buildlog_consultant::problems::common::VcsControlDirectory
     }
 }
 
+/// Dependency on a Lua module.
+///
+/// This represents a dependency on a Lua module that can be loaded
+/// with the require() function.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct LuaModuleDependency {
+    /// Name of the Lua module
     module: String,
 }
 
 impl LuaModuleDependency {
+    /// Create a new LuaModuleDependency.
+    ///
+    /// # Arguments
+    /// * `module` - Name of the Lua module
+    ///
+    /// # Returns
+    /// A new LuaModuleDependency instance
     pub fn new(module: &str) -> Self {
         Self {
             module: module.to_string(),
@@ -229,15 +281,32 @@ impl ToDependency for buildlog_consultant::problems::common::MissingLuaModule {
     }
 }
 
+/// Dependency on a Rust crate from crates.io.
+///
+/// This represents a dependency on a Rust crate that can be fetched
+/// from the crates.io registry.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct CargoCrateDependency {
+    /// Name of the crate
     pub name: String,
+    /// Optional list of required features
     pub features: Option<Vec<String>>,
+    /// Optional API version requirement
     pub api_version: Option<String>,
+    /// Optional minimum version requirement
     pub minimum_version: Option<String>,
 }
 
 impl CargoCrateDependency {
+    /// Create a new CargoCrateDependency with features and API version.
+    ///
+    /// # Arguments
+    /// * `name` - Name of the crate
+    /// * `features` - Optional list of required features
+    /// * `api_version` - Optional API version requirement
+    ///
+    /// # Returns
+    /// A new CargoCrateDependency instance
     pub fn new(name: &str, features: Option<Vec<&str>>, api_version: Option<&str>) -> Self {
         Self {
             name: name.to_string(),
@@ -247,6 +316,13 @@ impl CargoCrateDependency {
         }
     }
 
+    /// Create a new CargoCrateDependency with just a name.
+    ///
+    /// # Arguments
+    /// * `name` - Name of the crate
+    ///
+    /// # Returns
+    /// A new CargoCrateDependency instance without features or version requirements
     pub fn simple(name: &str) -> Self {
         Self {
             name: name.to_string(),
@@ -341,6 +417,7 @@ impl crate::dependencies::debian::FromDebianDependency for CargoCrateDependency
     fn from_debian_dependency(
         dependency: &crate::dependencies::debian::DebianDependency,
     ) -> Option<Box<dyn Dependency>> {
+        use std::collections::HashSet;
         let (name, min_version) =
             crate::dependencies::debian::extract_simple_min_version(dependency)?;
         let (_, name, api_version, features) =
@@ -371,17 +448,34 @@ impl ToDependency for buildlog_consultant::problems::common::MissingRustCompiler
 impl crate::upstream::FindUpstream for CargoCrateDependency {
     fn find_upstream(&self) -> Option<crate::upstream::UpstreamMetadata> {
         let rt = tokio::runtime::Runtime::new().unwrap();
-        rt.block_on(upstream_ontologist::providers::rust::remote_crate_data(&self.name)).ok()
+        rt.block_on(upstream_ontologist::providers::rust::remote_crate_data(
+            &self.name,
+        ))
+        .ok()
     }
 }
 
+/// Dependency on a pkg-config module.
+///
+/// This represents a dependency on a library that can be found
+/// and configured using the pkg-config system.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct PkgConfigDependency {
+    /// Name of the pkg-config module
     module: String,
+    /// Optional minimum version requirement
     minimum_version: Option<String>,
 }
 
 impl PkgConfigDependency {
+    /// Create a new PkgConfigDependency with a version requirement.
+    ///
+    /// # Arguments
+    /// * `module` - Name of the pkg-config module
+    /// * `minimum_version` - Optional minimum version requirement
+    ///
+    /// # Returns
+    /// A new PkgConfigDependency instance
     pub fn new(module: &str, minimum_version: Option<&str>) -> Self {
         Self {
             module: module.to_string(),
@@ -389,6 +483,13 @@ impl PkgConfigDependency {
         }
     }
 
+    /// Create a new PkgConfigDependency without a version requirement.
+    ///
+    /// # Arguments
+    /// * `module` - Name of the pkg-config module
+    ///
+    /// # Returns
+    /// A new PkgConfigDependency instance without a version requirement
     pub fn simple(module: &str) -> Self {
         Self {
             module: module.to_string(),
@@ -501,13 +602,18 @@ impl ToDependency for buildlog_consultant::problems::common::MissingPkgConfig {
     fn to_dependency(&self) -> Option<Box<dyn Dependency>> {
         Some(Box::new(PkgConfigDependency::new(
             &self.module,
-            self.minimum_version.as_ref().map(|s| s.as_str()),
+            self.minimum_version.as_deref(),
         )))
     }
 }
 
+/// Dependency on a file or directory at a specific path.
+///
+/// This represents a dependency on a file or directory that must
+/// exist at a specific path in the filesystem.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct PathDependency {
+    /// Path to the required file or directory
     path: PathBuf,
 }
 
@@ -518,6 +624,13 @@ impl From<PathBuf> for PathDependency {
 }
 
 impl PathDependency {
+    /// Create a new PathDependency.
+    ///
+    /// # Arguments
+    /// * `path` - Path to the required file or directory
+    ///
+    /// # Returns
+    /// A new PathDependency instance
     pub fn new(path: &str) -> Self {
         Self {
             path: PathBuf::from(path),
@@ -571,12 +684,24 @@ impl ToDependency for buildlog_consultant::problems::common::MissingFile {
     }
 }
 
+/// Dependency on a C header file.
+///
+/// This represents a dependency on a C header file that must
+/// be available in the system include paths.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct CHeaderDependency {
+    /// Name of the C header file
     header: String,
 }
 
 impl CHeaderDependency {
+    /// Create a new CHeaderDependency.
+    ///
+    /// # Arguments
+    /// * `header` - Name of the C header file
+    ///
+    /// # Returns
+    /// A new CHeaderDependency instance
     pub fn new(header: &str) -> Self {
         Self {
             header: header.to_string(),
@@ -658,6 +783,10 @@ impl ToDependency for buildlog_consultant::problems::common::MissingCHeader {
     }
 }
 
+/// Dependency on a JavaScript runtime environment.
+///
+/// This represents a dependency on a JavaScript runtime environment
+/// like Node.js or a web browser.
 #[derive(Debug, Clone)]
 pub struct JavaScriptRuntimeDependency;
 
@@ -710,12 +839,24 @@ impl ToDependency for buildlog_consultant::problems::common::MissingJavaScriptRu
     }
 }
 
+/// Dependency on a Vala package.
+///
+/// This represents a dependency on a Vala package that can be located
+/// using pkg-config.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct ValaPackageDependency {
+    /// Name of the Vala package
     package: String,
 }
 
 impl ValaPackageDependency {
+    /// Create a new ValaPackageDependency.
+    ///
+    /// # Arguments
+    /// * `package` - Name of the Vala package
+    ///
+    /// # Returns
+    /// A new ValaPackageDependency instance
     pub fn new(package: &str) -> Self {
         Self {
             package: package.to_string(),
@@ -724,14 +865,34 @@ impl ValaPackageDependency {
 }
 
 impl Dependency for ValaPackageDependency {
+    /// Returns the family name for this dependency type.
+    ///
+    /// # Returns
+    /// The string "vala-package"
     fn family(&self) -> &'static str {
         "vala-package"
     }
 
+    /// Checks if the dependency is present in the project context.
+    ///
+    /// # Arguments
+    /// * `_session` - The session in which to check
+    ///
+    /// # Returns
+    /// This method is not implemented yet and will panic if called
     fn project_present(&self, _session: &dyn Session) -> bool {
         todo!()
     }
 
+    /// Checks if the Vala package is available in the system.
+    ///
+    /// Uses pkg-config to check if the package exists.
+    ///
+    /// # Arguments
+    /// * `session` - The session in which to check
+    ///
+    /// # Returns
+    /// `true` if the package exists, `false` otherwise
     fn present(&self, session: &dyn Session) -> bool {
         session
             .command(vec!["pkg-config", "--exists", &self.package])
@@ -742,6 +903,10 @@ impl Dependency for ValaPackageDependency {
             .success()
     }
 
+    /// Returns this dependency as a trait object.
+    ///
+    /// # Returns
+    /// Reference to this object as a trait object
     fn as_any(&self) -> &dyn std::any::Any {
         self
     }
@@ -749,6 +914,16 @@ impl Dependency for ValaPackageDependency {
 
 #[cfg(feature = "debian")]
 impl crate::dependencies::debian::IntoDebianDependency for ValaPackageDependency {
+    /// Convert this dependency to a list of Debian package dependencies.
+    ///
+    /// Attempts to find the Debian packages that provide the Vala package by
+    /// searching for .vapi files in standard locations.
+    ///
+    /// # Arguments
+    /// * `apt` - The APT package manager to use for queries
+    ///
+    /// # Returns
+    /// A list of Debian package dependencies if found, or None if not found
     fn try_into_debian_dependency(
         &self,
         apt: &crate::debian::apt::AptManager,
@@ -771,18 +946,36 @@ impl crate::dependencies::debian::IntoDebianDependency for ValaPackageDependency
 }
 
 impl ToDependency for buildlog_consultant::problems::common::MissingValaPackage {
+    /// Convert a MissingValaPackage problem to a Dependency.
+    ///
+    /// # Returns
+    /// A ValaPackageDependency boxed as a Dependency trait object
     fn to_dependency(&self) -> Option<Box<dyn Dependency>> {
         Some(Box::new(ValaPackageDependency::new(&self.0)))
     }
 }
 
+/// Dependency on a Ruby gem.
+///
+/// This represents a dependency on a Ruby gem that can be installed
+/// via RubyGems or bundler.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct RubyGemDependency {
+    /// Name of the Ruby gem
     gem: String,
+    /// Optional minimum version requirement
     minimum_version: Option<String>,
 }
 
 impl RubyGemDependency {
+    /// Create a new RubyGemDependency with optional version constraint.
+    ///
+    /// # Arguments
+    /// * `gem` - Name of the Ruby gem
+    /// * `minimum_version` - Optional minimum version requirement
+    ///
+    /// # Returns
+    /// A new RubyGemDependency instance
     pub fn new(gem: &str, minimum_version: Option<&str>) -> Self {
         Self {
             gem: gem.to_string(),
@@ -790,6 +983,13 @@ impl RubyGemDependency {
         }
     }
 
+    /// Create a new RubyGemDependency without version constraints.
+    ///
+    /// # Arguments
+    /// * `gem` - Name of the Ruby gem
+    ///
+    /// # Returns
+    /// A new RubyGemDependency instance without version constraints
     pub fn simple(gem: &str) -> Self {
         Self {
             gem: gem.to_string(),
@@ -799,10 +999,24 @@ impl RubyGemDependency {
 }
 
 impl Dependency for RubyGemDependency {
+    /// Returns the family name for this dependency type.
+    ///
+    /// # Returns
+    /// The string "ruby-gem"
     fn family(&self) -> &'static str {
         "ruby-gem"
     }
 
+    /// Checks if the gem is present in the project's bundle.
+    ///
+    /// Uses the `bundle list` command to check if the gem is available
+    /// with the required version in the project's Gemfile.
+    ///
+    /// # Arguments
+    /// * `session` - The session in which to check
+    ///
+    /// # Returns
+    /// `true` if the gem exists in the project's bundle, `false` otherwise
     fn project_present(&self, session: &dyn Session) -> bool {
         let mut cmd = vec!["bundle".to_string(), "list".to_string()];
         if let Some(minimum_version) = &self.minimum_version {
@@ -818,6 +1032,16 @@ impl Dependency for RubyGemDependency {
             .success()
     }
 
+    /// Checks if the gem is installed in the system.
+    ///
+    /// Uses the `gem list --local` command to check if the gem is available
+    /// with the required version.
+    ///
+    /// # Arguments
+    /// * `session` - The session in which to check
+    ///
+    /// # Returns
+    /// `true` if the gem exists in the system, `false` otherwise
     fn present(&self, session: &dyn Session) -> bool {
         let mut cmd = vec!["gem".to_string(), "list".to_string(), "--local".to_string()];
         if let Some(minimum_version) = &self.minimum_version {
@@ -832,6 +1056,10 @@ impl Dependency for RubyGemDependency {
             .success()
     }
 
+    /// Returns this dependency as a trait object.
+    ///
+    /// # Returns
+    /// Reference to this object as a trait object
     fn as_any(&self) -> &dyn std::any::Any {
         self
     }
@@ -839,6 +1067,16 @@ impl Dependency for RubyGemDependency {
 
 #[cfg(feature = "debian")]
 impl crate::dependencies::debian::IntoDebianDependency for RubyGemDependency {
+    /// Convert this dependency to a list of Debian package dependencies.
+    ///
+    /// Attempts to find the Debian packages that provide the Ruby gem by
+    /// searching for .gemspec files in standard locations.
+    ///
+    /// # Arguments
+    /// * `apt` - The APT package manager to use for queries
+    ///
+    /// # Returns
+    /// A list of Debian package dependencies if found, or None if not found
     fn try_into_debian_dependency(
         &self,
         apt: &crate::debian::apt::AptManager,
@@ -878,6 +1116,17 @@ impl crate::dependencies::debian::IntoDebianDependency for RubyGemDependency {
 
 #[cfg(feature = "debian")]
 impl crate::dependencies::debian::FromDebianDependency for RubyGemDependency {
+    /// Create a RubyGemDependency from a Debian dependency.
+    ///
+    /// Extracts the gem name and version from a Debian package name,
+    /// assuming the package name follows the ruby-* naming convention.
+    ///
+    /// # Arguments
+    /// * `dependency` - The Debian dependency to convert
+    ///
+    /// # Returns
+    /// A RubyGemDependency boxed as a Dependency trait object if conversion is possible,
+    /// None otherwise
     fn from_debian_dependency(
         dependency: &crate::dependencies::debian::DebianDependency,
     ) -> Option<Box<dyn Dependency>> {
@@ -893,28 +1142,52 @@ impl crate::dependencies::debian::FromDebianDependency for RubyGemDependency {
 }
 
 impl ToDependency for buildlog_consultant::problems::common::MissingRubyGem {
+    /// Convert a MissingRubyGem problem to a Dependency.
+    ///
+    /// # Returns
+    /// A RubyGemDependency boxed as a Dependency trait object
     fn to_dependency(&self) -> Option<Box<dyn Dependency>> {
         Some(Box::new(RubyGemDependency::new(
             &self.gem,
-            self.version.as_ref().map(|s| s.as_str()),
+            self.version.as_deref(),
         )))
     }
 }
 
 #[cfg(feature = "upstream")]
 impl crate::upstream::FindUpstream for RubyGemDependency {
+    /// Find upstream metadata for this Ruby gem.
+    ///
+    /// Uses the upstream-ontologist crate to fetch metadata about the gem
+    /// from RubyGems.org.
+    ///
+    /// # Returns
+    /// Upstream metadata if available, None otherwise
     fn find_upstream(&self) -> Option<crate::upstream::UpstreamMetadata> {
         let rt = tokio::runtime::Runtime::new().unwrap();
-        rt.block_on(upstream_ontologist::providers::ruby::remote_rubygem_metadata(&self.gem)).ok()
+        rt.block_on(upstream_ontologist::providers::ruby::remote_rubygem_metadata(&self.gem))
+            .ok()
     }
 }
 
+/// Dependency on a Debian debhelper addon.
+///
+/// This represents a dependency on a debhelper addon that can be used
+/// in Debian packaging with the `dh` command.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct DhAddonDependency {
+    /// Name of the debhelper addon
     addon: String,
 }
 
 impl DhAddonDependency {
+    /// Create a new DhAddonDependency.
+    ///
+    /// # Arguments
+    /// * `addon` - Name of the debhelper addon
+    ///
+    /// # Returns
+    /// A new DhAddonDependency instance
     pub fn new(addon: &str) -> Self {
         Self {
             addon: addon.to_string(),
@@ -923,18 +1196,40 @@ impl DhAddonDependency {
 }
 
 impl Dependency for DhAddonDependency {
+    /// Returns the family name for this dependency type.
+    ///
+    /// # Returns
+    /// The string "dh-addon"
     fn family(&self) -> &'static str {
         "dh-addon"
     }
 
+    /// Checks if the dependency is present in the system.
+    ///
+    /// # Arguments
+    /// * `_session` - The session in which to check
+    ///
+    /// # Returns
+    /// This method is not implemented yet and will panic if called
     fn present(&self, _session: &dyn Session) -> bool {
         todo!()
     }
 
+    /// Checks if the dependency is present in the project context.
+    ///
+    /// # Arguments
+    /// * `_session` - The session in which to check
+    ///
+    /// # Returns
+    /// This method is not implemented yet and will panic if called
     fn project_present(&self, _session: &dyn Session) -> bool {
         todo!()
     }
 
+    /// Returns this dependency as a trait object.
+    ///
+    /// # Returns
+    /// Reference to this object as a trait object
     fn as_any(&self) -> &dyn std::any::Any {
         self
     }
@@ -942,6 +1237,16 @@ impl Dependency for DhAddonDependency {
 
 #[cfg(feature = "debian")]
 impl crate::dependencies::debian::IntoDebianDependency for DhAddonDependency {
+    /// Convert this dependency to a list of Debian package dependencies.
+    ///
+    /// Attempts to find the Debian packages that provide the debhelper addon by
+    /// searching for addon Perl modules in standard locations.
+    ///
+    /// # Arguments
+    /// * `apt` - The APT package manager to use for queries
+    ///
+    /// # Returns
+    /// A list of Debian package dependencies if found, or None if not found
     fn try_into_debian_dependency(
         &self,
         apt: &crate::debian::apt::AptManager,
@@ -964,17 +1269,33 @@ impl crate::dependencies::debian::IntoDebianDependency for DhAddonDependency {
 }
 
 impl ToDependency for buildlog_consultant::problems::common::DhAddonLoadFailure {
+    /// Convert a DhAddonLoadFailure problem to a Dependency.
+    ///
+    /// # Returns
+    /// A DhAddonDependency boxed as a Dependency trait object
     fn to_dependency(&self) -> Option<Box<dyn Dependency>> {
         Some(Box::new(DhAddonDependency::new(&self.path)))
     }
 }
 
+/// Dependency on a system library.
+///
+/// This represents a dependency on a shared library that can be linked
+/// against using the -l flag with the linker.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct LibraryDependency {
+    /// Name of the library (without the lib prefix)
     library: String,
 }
 
 impl LibraryDependency {
+    /// Create a new LibraryDependency.
+    ///
+    /// # Arguments
+    /// * `library` - Name of the library (without the lib prefix)
+    ///
+    /// # Returns
+    /// A new LibraryDependency instance
     pub fn new(library: &str) -> Self {
         Self {
             library: library.to_string(),
@@ -983,10 +1304,23 @@ impl LibraryDependency {
 }
 
 impl Dependency for LibraryDependency {
+    /// Returns the family name for this dependency type.
+    ///
+    /// # Returns
+    /// The string "library"
     fn family(&self) -> &'static str {
         "library"
     }
 
+    /// Checks if the library is present in the system.
+    ///
+    /// Uses the `ld` command to check if the library can be linked against.
+    ///
+    /// # Arguments
+    /// * `session` - The session in which to check
+    ///
+    /// # Returns
+    /// `true` if the library exists and can be linked against, `false` otherwise
     fn present(&self, session: &dyn Session) -> bool {
         session
             .command(vec!["ld", "-l", &self.library])
@@ -997,10 +1331,21 @@ impl Dependency for LibraryDependency {
             .success()
     }
 
+    /// Checks if the dependency is present in the project context.
+    ///
+    /// # Arguments
+    /// * `_session` - The session in which to check
+    ///
+    /// # Returns
+    /// This method is not implemented yet and will panic if called
     fn project_present(&self, _session: &dyn Session) -> bool {
         todo!()
     }
 
+    /// Returns this dependency as a trait object.
+    ///
+    /// # Returns
+    /// Reference to this object as a trait object
     fn as_any(&self) -> &dyn std::any::Any {
         self
     }
@@ -1034,13 +1379,27 @@ impl ToDependency for buildlog_consultant::problems::common::MissingLibrary {
     }
 }
 
+/// Dependency on a static library.
+///
+/// This represents a dependency on a static library (.a file) that
+/// can be linked against at build time.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct StaticLibraryDependency {
+    /// Name of the library (without the lib prefix)
     library: String,
+    /// Filename of the library archive
     filename: String,
 }
 
 impl StaticLibraryDependency {
+    /// Create a new StaticLibraryDependency.
+    ///
+    /// # Arguments
+    /// * `library` - Name of the library (without the lib prefix)
+    /// * `filename` - Filename of the library archive
+    ///
+    /// # Returns
+    /// A new StaticLibraryDependency instance
     pub fn new(library: &str, filename: &str) -> Self {
         Self {
             library: library.to_string(),
@@ -1050,18 +1409,40 @@ impl StaticLibraryDependency {
 }
 
 impl Dependency for StaticLibraryDependency {
+    /// Returns the family name for this dependency type.
+    ///
+    /// # Returns
+    /// The string "static-library"
     fn family(&self) -> &'static str {
         "static-library"
     }
 
+    /// Checks if the static library is present in the system.
+    ///
+    /// # Arguments
+    /// * `_session` - The session in which to check
+    ///
+    /// # Returns
+    /// This method is not implemented yet and will panic if called
     fn present(&self, _session: &dyn Session) -> bool {
         todo!()
     }
 
+    /// Checks if the dependency is present in the project context.
+    ///
+    /// # Arguments
+    /// * `_session` - The session in which to check
+    ///
+    /// # Returns
+    /// This method is not implemented yet and will panic if called
     fn project_present(&self, _session: &dyn Session) -> bool {
         todo!()
     }
 
+    /// Returns this dependency as a trait object.
+    ///
+    /// # Returns
+    /// Reference to this object as a trait object
     fn as_any(&self) -> &dyn std::any::Any {
         self
     }
@@ -1096,12 +1477,24 @@ impl ToDependency for buildlog_consultant::problems::common::MissingStaticLibrar
     }
 }
 
+/// Dependency on a Ruby source file.
+///
+/// This represents a dependency on a Ruby source file that can be
+/// loaded with the require() function in Ruby.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct RubyFileDependency {
+    /// Name of the Ruby file (without .rb extension)
     filename: String,
 }
 
 impl RubyFileDependency {
+    /// Create a new RubyFileDependency.
+    ///
+    /// # Arguments
+    /// * `filename` - Name of the Ruby file (without .rb extension)
+    ///
+    /// # Returns
+    /// A new RubyFileDependency instance
     pub fn new(filename: &str) -> Self {
         Self {
             filename: filename.to_string(),
@@ -1175,13 +1568,27 @@ impl ToDependency for buildlog_consultant::problems::common::MissingRubyFile {
     }
 }
 
+/// Dependency on a file managed by Sprockets asset pipeline.
+///
+/// This represents a dependency on a file that can be processed by the
+/// Sprockets asset pipeline in Ruby on Rails.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct SprocketsFileDependency {
+    /// MIME type of the file (e.g., "application/javascript")
     content_type: String,
+    /// Name of the asset
     name: String,
 }
 
 impl SprocketsFileDependency {
+    /// Create a new SprocketsFileDependency.
+    ///
+    /// # Arguments
+    /// * `content_type` - MIME type of the file
+    /// * `name` - Name of the asset
+    ///
+    /// # Returns
+    /// A new SprocketsFileDependency instance
     pub fn new(content_type: &str, name: &str) -> Self {
         Self {
             content_type: content_type.to_string(),
@@ -1245,13 +1652,27 @@ impl ToDependency for buildlog_consultant::problems::common::MissingSprocketsFil
     }
 }
 
+/// Dependency on a CMake module or config file.
+///
+/// This represents a dependency on a CMake module or configuration file
+/// that can be found with find_package() in CMake.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct CMakeFileDependency {
+    /// Name of the CMake file
     filename: String,
+    /// Optional version requirement
     version: Option<String>,
 }
 
 impl CMakeFileDependency {
+    /// Create a new CMakeFileDependency with optional version requirement.
+    ///
+    /// # Arguments
+    /// * `filename` - Name of the CMake file
+    /// * `version` - Optional version requirement
+    ///
+    /// # Returns
+    /// A new CMakeFileDependency instance
     pub fn new(filename: &str, version: Option<&str>) -> Self {
         Self {
             filename: filename.to_string(),
@@ -1259,6 +1680,13 @@ impl CMakeFileDependency {
         }
     }
 
+    /// Create a new CMakeFileDependency without version requirement.
+    ///
+    /// # Arguments
+    /// * `filename` - Name of the CMake file
+    ///
+    /// # Returns
+    /// A new CMakeFileDependency instance without version requirement
     pub fn simple(filename: &str) -> Self {
         Self {
             filename: filename.to_string(),
@@ -1308,15 +1736,20 @@ impl ToDependency for buildlog_consultant::problems::common::CMakeFilesMissing {
     fn to_dependency(&self) -> Option<Box<dyn Dependency>> {
         Some(Box::new(CMakeFileDependency::new(
             &self.filenames[0],
-            self.version.as_ref().map(|s| s.as_str()),
+            self.version.as_deref(),
         )))
     }
 }
 
+/// Type of Maven artifact.
+///
+/// Represents different kinds of Maven artifacts that can be dependencies.
 #[derive(Debug, Clone, Serialize, Deserialize, PartialEq, Eq, Default)]
 pub enum MavenArtifactKind {
+    /// Java archive (JAR) file
     #[default]
     Jar,
+    /// Project Object Model (POM) file
     Pom,
 }
 
@@ -1341,15 +1774,33 @@ impl std::str::FromStr for MavenArtifactKind {
     }
 }
 
+/// Dependency on a Maven artifact.
+///
+/// This represents a dependency on a Maven artifact identified by
+/// group ID, artifact ID, and optionally version and kind.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct MavenArtifactDependency {
+    /// Maven group ID (e.g., "org.apache.maven")
     pub group_id: String,
+    /// Maven artifact ID (e.g., "maven-core")
     pub artifact_id: String,
+    /// Optional version requirement (e.g., "3.8.6")
     pub version: Option<String>,
+    /// Optional kind of artifact (JAR or POM)
     pub kind: Option<MavenArtifactKind>,
 }
 
 impl MavenArtifactDependency {
+    /// Create a new MavenArtifactDependency with all details.
+    ///
+    /// # Arguments
+    /// * `group_id` - Maven group ID
+    /// * `artifact_id` - Maven artifact ID
+    /// * `version` - Optional version requirement
+    /// * `kind` - Optional artifact kind string ("jar" or "pom")
+    ///
+    /// # Returns
+    /// A new MavenArtifactDependency instance
     pub fn new(
         group_id: &str,
         artifact_id: &str,
@@ -1364,6 +1815,14 @@ impl MavenArtifactDependency {
         }
     }
 
+    /// Create a new MavenArtifactDependency with just group and artifact IDs.
+    ///
+    /// # Arguments
+    /// * `group_id` - Maven group ID
+    /// * `artifact_id` - Maven artifact ID
+    ///
+    /// # Returns
+    /// A new MavenArtifactDependency instance without version or kind specified
     pub fn simple(group_id: &str, artifact_id: &str) -> Self {
         Self {
             group_id: group_id.to_string(),
@@ -1503,6 +1962,10 @@ impl ToDependency for buildlog_consultant::problems::common::MissingMavenArtifac
     }
 }
 
+/// Dependency on GNOME common build tools.
+///
+/// This represents a dependency on the gnome-common package which provides
+/// common build infrastructure for GNOME projects.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct GnomeCommonDependency;
 
@@ -1547,12 +2010,23 @@ impl ToDependency for buildlog_consultant::problems::common::MissingGnomeCommonD
     }
 }
 
+/// Dependency on a Qt module.
+///
+/// This represents a dependency on a Qt module like QtCore, QtGui, etc.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct QtModuleDependency {
+    /// Name of the Qt module
     module: String,
 }
 
 impl QtModuleDependency {
+    /// Create a new QtModuleDependency.
+    ///
+    /// # Arguments
+    /// * `module` - Name of the Qt module
+    ///
+    /// # Returns
+    /// A new QtModuleDependency instance
     pub fn new(module: &str) -> Self {
         Self {
             module: module.to_string(),
@@ -1613,6 +2087,10 @@ impl ToDependency for buildlog_consultant::problems::common::MissingQtModules {
     }
 }
 
+/// Dependency on the Qt toolkit.
+///
+/// This represents a dependency on the Qt toolkit as a whole,
+/// specifically the qmake tool for building Qt projects.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct QTDependency;
 
@@ -1662,6 +2140,10 @@ impl ToDependency for buildlog_consultant::problems::common::MissingQt {
     }
 }
 
+/// Dependency on the X11 window system.
+///
+/// This represents a dependency on the X Window System (X11),
+/// which is needed for graphical applications.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct X11Dependency;
 
@@ -1701,12 +2183,24 @@ impl ToDependency for buildlog_consultant::problems::common::MissingX11 {
     }
 }
 
+/// Dependency on certificate authority certificates.
+///
+/// This represents a dependency on CA certificates needed for
+/// secure HTTPS connections to specific URLs.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct CertificateAuthorityDependency {
+    /// URL that requires certificate verification
     url: String,
 }
 
 impl CertificateAuthorityDependency {
+    /// Create a new CertificateAuthorityDependency.
+    ///
+    /// # Arguments
+    /// * `url` - URL that requires certificate verification
+    ///
+    /// # Returns
+    /// A new CertificateAuthorityDependency instance
     pub fn new(url: &str) -> Self {
         Self {
             url: url.to_string(),
@@ -1749,6 +2243,10 @@ impl ToDependency for buildlog_consultant::problems::common::UnknownCertificateA
     }
 }
 
+/// Dependency on the GNU Libtool.
+///
+/// This represents a dependency on the GNU Libtool, which is used to
+/// create portable libraries in autotools-based projects.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct LibtoolDependency;
 
@@ -1793,12 +2291,24 @@ impl ToDependency for buildlog_consultant::problems::common::MissingLibtool {
     }
 }
 
+/// Dependency on a Boost library component.
+///
+/// This represents a dependency on a specific component of the Boost C++ Libraries,
+/// such as boost_system, boost_filesystem, etc.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct BoostComponentDependency {
+    /// Name of the Boost component
     name: String,
 }
 
 impl BoostComponentDependency {
+    /// Create a new BoostComponentDependency.
+    ///
+    /// # Arguments
+    /// * `name` - Name of the Boost component
+    ///
+    /// # Returns
+    /// A new BoostComponentDependency instance
     pub fn new(name: &str) -> Self {
         Self {
             name: name.to_string(),
@@ -1853,12 +2363,24 @@ impl crate::dependencies::debian::IntoDebianDependency for BoostComponentDepende
     }
 }
 
+/// Dependency on a KDE Frameworks 5 component.
+///
+/// This represents a dependency on a specific component of the
+/// KDE Frameworks 5, such as KF5Auth, KF5CoreAddons, etc.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct KF5ComponentDependency {
+    /// Name of the KF5 component
     name: String,
 }
 
 impl KF5ComponentDependency {
+    /// Create a new KF5ComponentDependency.
+    ///
+    /// # Arguments
+    /// * `name` - Name of the KF5 component
+    ///
+    /// # Returns
+    /// A new KF5ComponentDependency instance
     pub fn new(name: &str) -> Self {
         Self {
             name: name.to_string(),
@@ -1927,12 +2449,24 @@ impl ToDependency for buildlog_consultant::problems::common::MissingCMakeCompone
     }
 }
 
+/// Dependency on a Gnulib directory.
+///
+/// This represents a dependency on a specific directory containing
+/// Gnulib code, which is a collection of portable C functions.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct GnulibDirectoryDependency {
+    /// Path to the Gnulib directory
     directory: PathBuf,
 }
 
 impl GnulibDirectoryDependency {
+    /// Create a new GnulibDirectoryDependency.
+    ///
+    /// # Arguments
+    /// * `directory` - Path to the Gnulib directory
+    ///
+    /// # Returns
+    /// A new GnulibDirectoryDependency instance
     pub fn new(directory: &str) -> Self {
         Self {
             directory: PathBuf::from(directory),
@@ -1960,17 +2494,29 @@ impl Dependency for GnulibDirectoryDependency {
 impl ToDependency for buildlog_consultant::problems::common::MissingGnulibDirectory {
     fn to_dependency(&self) -> Option<Box<dyn Dependency>> {
         Some(Box::new(GnulibDirectoryDependency {
-            directory: PathBuf::from(self.0.clone()),
+            directory: self.0.clone(),
         }))
     }
 }
 
+/// Dependency on a GObject Introspection typelib.
+///
+/// This represents a dependency on a GObject Introspection typelib file,
+/// which provides language bindings for GObject-based libraries.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct IntrospectionTypelibDependency {
+    /// Name of the library with introspection data
     library: String,
 }
 
 impl IntrospectionTypelibDependency {
+    /// Create a new IntrospectionTypelibDependency.
+    ///
+    /// # Arguments
+    /// * `library` - Name of the library with introspection data
+    ///
+    /// # Returns
+    /// A new IntrospectionTypelibDependency instance
     pub fn new(library: &str) -> Self {
         Self {
             library: library.to_string(),
